/*
** ATOP - System & Process Monitor
**
** The program 'atop' offers the possibility to view the activity of
** the system on system-level as well as process-level.
**
** Include-file describing system-level counters maintained.
** ================================================================
** Author:      Gerlof Langeveld - AT Computing, Nijmegen, Holland
** E-mail:      gerlof@ATComputing.nl
** Date:        November 1996
** LINUX-port:  June 2000
**
** This program is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by the
** Free Software Foundation; either version 2, or (at your option) any
** later version.
**
** This program is distributed in the hope that it will be useful, but
** WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU General Public License for more details.
*/
struct	cpustat {
	unsigned long	stime;	/* system time in clock ticks		*/
	unsigned long	utime;	/* user   time in clock ticks		*/
	unsigned long	ntime;	/* nice   time in clock ticks		*/
	unsigned long	itime;	/* idle   time in clock ticks		*/

	unsigned long	devint;	/* number of device interrupts 		*/
	unsigned long	csw;	/* number of context switches		*/
	unsigned char	numcpu;	/* number of cpu's 			*/
};

struct	memstat {
	int	physmem;	/* number of pages physical memory	*/
	int	freemem;	/* number of free   pages		*/
	int	buffermem;	/* number of buffer pages		*/
	int	sharedmem;	/* number of shared pages		*/
	int	cachemem;	/* number of cache  pages		*/

	unsigned long swouts;	/* number of pages swapped out		*/
	unsigned long swins;	/* number of pages swapped in		*/

	int	totswap;	/* number of pages in swap		*/
	int	freeswap;	/* number of free swap pages		*/
};

struct	netstat {
	unsigned long	tcpin;	/* TCP received packets			*/
	unsigned long	tcpout;	/* TCP transmitted packets		*/

	unsigned long	udpin;	/* UDP received packets			*/
	unsigned long	udpout;	/* UDP transmitted packets		*/

	unsigned long	ipin;	/* IP  received packets			*/
	unsigned long	ipout;	/* IP  transmitted packets		*/
	unsigned long	ipindel;/* IP  locally delivered packets	*/
	unsigned long	ipfrw;	/* IP  forwarded packets		*/
};

struct	intfstat {
        char            name[16];	/* empty string for last        */
        unsigned long   rbyte;	/* number of read bytes                 */
        unsigned long   rpack;	/* number of read packets               */
        unsigned long   sbyte;	/* number of written bytes              */
        unsigned long   spack;	/* number of written packets            */
};

struct	xdskstat {
        char            name[32];	/* empty string for last        */
        unsigned long   nread;	/* number of read  transfers            */
        unsigned long   nrblk;	/* number of sectors read               */
        unsigned long   nwrite;	/* number of write transfers            */
        unsigned long   nwblk;	/* number of sectors written            */
        unsigned long   io_ms;	/* number of millisecs spent for I/O    */
        unsigned long   avque;	/* average queue length                 */
};


#define	MAXDSK	32
#define	MAXINTF	16

struct	sstat {
	struct cpustat	  cpu;
	struct memstat	  mem;
	struct netstat	  net;
	struct intfstat	  intf[MAXINTF];
	struct xdskstat   xdsk[MAXDSK];
};

/*
** prototypes
*/
void	photosyst (struct sstat *);
void	deviatsyst(struct sstat *, struct sstat *, struct sstat *);
